@@ -2,9 +2,8 @@
     where <- match(paste("package:", pkg, sep = ""), search())
     ver <- read.dcf(file.path(lib, pkg, "DESCRIPTION"), "Version")
     ver <- as.character(ver)
-    cat(paste("UCLA Bootstrap Routines (version ", ver, ")\n", sep = ""))
+    cat(paste("Simple Bootstrap Routines (version ", ver, ")\n", sep = ""))
 
-    if(!require(boot))
-        stop("package `boot' is required")
+    library(boot)
     library(modreg)
 }
